@@ -4,5 +4,8 @@ test_that("check_tz", {
   })
   rlang::local_options(lifecycle_verbosity = "quiet")
   x <- check_tz(as.POSIXct("1970-01-01", tz = "GMT"))
-  expect_error(check_tz(x, "UTC"), "x's time zone must be 'UTC' not [(]'GMT'[)]")
+  expect_error(
+    check_tz(x, "UTC"),
+    "x's time zone must be 'UTC' not [(]'GMT'[)]"
+  )
 })
